==> aws-sdk-cpp-1.11.710-1-x86_64.pkg.tar.zst: usr/include/aws/pinpoint-sms-voice-v2/model/SendTextMessageRequest.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/utils/memory/stl/AWSMap.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/pinpoint-sms-voice-v2/PinpointSMSVoiceV2Request.h>
#include <aws/pinpoint-sms-voice-v2/PinpointSMSVoiceV2_EXPORTS.h>
#include <aws/pinpoint-sms-voice-v2/model/DestinationCountryParameterKey.h>
#include <aws/pinpoint-sms-voice-v2/model/MessageType.h>

#include <utility>

namespace Aws {
namespace PinpointSMSVoiceV2 {
namespace Model {

/**
 */
class SendTextMessageRequest : public PinpointSMSVoiceV2Request {
 public:
  AWS_PINPOINTSMSVOICEV2_API SendTextMessageRequest() = default;

  // Service request name is the Operation name which will send this request out,
  // each operation should has unique request name, so that we can get operation's name from this request.
  // Note: this is not true for response, multiple operations may have the same response name,
  // so we can not get operation's name from response.
  inline virtual const char* GetServiceRequestName() const override { return "SendTextMessage"; }

  AWS_PINPOINTSMSVOICEV2_API Aws::String SerializePayload() const override;

  AWS_PINPOINTSMSVOICEV2_API Aws::Http::HeaderValueCollection GetRequestSpecificHeaders() const override;

  ///@{
  /**
   * <p>The destination phone number in E.164 format.</p>
   */
  inline const Aws::String& GetDestinationPhoneNumber() const { return m_destinationPhoneNumber; }
  inline bool DestinationPhoneNumberHasBeenSet() const { return m_destinationPhoneNumberHasBeenSet; }
  template <typename DestinationPhoneNumberT = Aws::String>
  void SetDestinationPhoneNumber(DestinationPhoneNumberT&& value) {
    m_destinationPhoneNumberHasBeenSet = true;
    m_destinationPhoneNumber = std::forward<DestinationPhoneNumberT>(value);
  }
  template <typename DestinationPhoneNumberT = Aws::String>
  SendTextMessageRequest& WithDestinationPhoneNumber(DestinationPhoneNumberT&& value) {
    SetDestinationPhoneNumber(std::forward<DestinationPhoneNumberT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The origination identity of the message. This can be either the PhoneNumber,
   * PhoneNumberId, PhoneNumberArn, SenderId, SenderIdArn, PoolId, or PoolArn.</p>
   *  <p>If you are using a shared End User MessagingSMS resource then you
   * must use the full Amazon Resource Name(ARN).</p>
   */
  inline const Aws::String& GetOriginationIdentity() const { return m_originationIdentity; }
  inline bool OriginationIdentityHasBeenSet() const { return m_originationIdentityHasBeenSet; }
  template <typename OriginationIdentityT = Aws::String>
  void SetOriginationIdentity(OriginationIdentityT&& value) {
    m_originationIdentityHasBeenSet = true;
    m_originationIdentity = std::forward<OriginationIdentityT>(value);
  }
  template <typename OriginationIdentityT = Aws::String>
  SendTextMessageRequest& WithOriginationIdentity(OriginationIdentityT&& value) {
    SetOriginationIdentity(std::forward<OriginationIdentityT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The body of the text message.</p>
   */
  inline const Aws::String& GetMessageBody() const { return m_messageBody; }
  inline bool MessageBodyHasBeenSet() const { return m_messageBodyHasBeenSet; }
  template <typename MessageBodyT = Aws::String>
  void SetMessageBody(MessageBodyT&& value) {
    m_messageBodyHasBeenSet = true;
    m_messageBody = std::forward<MessageBodyT>(value);
  }
  template <typename MessageBodyT = Aws::String>
  SendTextMessageRequest& WithMessageBody(MessageBodyT&& value) {
    SetMessageBody(std::forward<MessageBodyT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The type of message. Valid values are for messages that are critical or
   * time-sensitive and PROMOTIONAL for messages that aren't critical or
   * time-sensitive.</p>
   */
  inline MessageType GetMessageType() const { return m_messageType; }
  inline bool MessageTypeHasBeenSet() const { return m_messageTypeHasBeenSet; }
  inline void SetMessageType(MessageType value) {
    m_messageTypeHasBeenSet = true;
    m_messageType = value;
  }
  inline SendTextMessageRequest& WithMessageType(MessageType value) {
    SetMessageType(value);
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>When you register a short code in the US, you must specify a program name. If
   * you don’t have a US short code, omit this attribute.</p>
   */
  inline const Aws::String& GetKeyword() const { return m_keyword; }
  inline bool KeywordHasBeenSet() const { return m_keywordHasBeenSet; }
  template <typename KeywordT = Aws::String>
  void SetKeyword(KeywordT&& value) {
    m_keywordHasBeenSet = true;
    m_keyword = std::forward<KeywordT>(value);
  }
  template <typename KeywordT = Aws::String>
  SendTextMessageRequest& WithKeyword(KeywordT&& value) {
    SetKeyword(std::forward<KeywordT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The name of the configuration set to use. This can be either the
   * ConfigurationSetName or ConfigurationSetArn.</p>
   */
  inline const Aws::String& GetConfigurationSetName() const { return m_configurationSetName; }
  inline bool ConfigurationSetNameHasBeenSet() const { return m_configurationSetNameHasBeenSet; }
  template <typename ConfigurationSetNameT = Aws::String>
  void SetConfigurationSetName(ConfigurationSetNameT&& value) {
    m_configurationSetNameHasBeenSet = true;
    m_configurationSetName = std::forward<ConfigurationSetNameT>(value);
  }
  template <typename ConfigurationSetNameT = Aws::String>
  SendTextMessageRequest& WithConfigurationSetName(ConfigurationSetNameT&& value) {
    SetConfigurationSetName(std::forward<ConfigurationSetNameT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The maximum amount that you want to spend, in US dollars, per each text
   * message. If the calculated amount to send the text message is greater than
   * <code>MaxPrice</code>, the message is not sent and an error is returned.</p>
   */
  inline const Aws::String& GetMaxPrice() const { return m_maxPrice; }
  inline bool MaxPriceHasBeenSet() const { return m_maxPriceHasBeenSet; }
  template <typename MaxPriceT = Aws::String>
  void SetMaxPrice(MaxPriceT&& value) {
    m_maxPriceHasBeenSet = true;
    m_maxPrice = std::forward<MaxPriceT>(value);
  }
  template <typename MaxPriceT = Aws::String>
  SendTextMessageRequest& WithMaxPrice(MaxPriceT&& value) {
    SetMaxPrice(std::forward<MaxPriceT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>How long the text message is valid for, in seconds. By default this is 72
   * hours. If the messages isn't handed off before the TTL expires we stop
   * attempting to hand off the message and return <code>TTL_EXPIRED</code>
   * event.</p>
   */
  inline int GetTimeToLive() const { return m_timeToLive; }
  inline bool TimeToLiveHasBeenSet() const { return m_timeToLiveHasBeenSet; }
  inline void SetTimeToLive(int value) {
    m_timeToLiveHasBeenSet = true;
    m_timeToLive = value;
  }
  inline SendTextMessageRequest& WithTimeToLive(int value) {
    SetTimeToLive(value);
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>You can specify custom data in this field. If you do, that data is logged to
   * the event destination.</p>
   */
  inline const Aws::Map<Aws::String, Aws::String>& GetContext() const { return m_context; }
  inline bool ContextHasBeenSet() const { return m_contextHasBeenSet; }
  template <typename ContextT = Aws::Map<Aws::String, Aws::String>>
  void SetContext(ContextT&& value) {
    m_contextHasBeenSet = true;
    m_context = std::forward<ContextT>(value);
  }
  template <typename ContextT = Aws::Map<Aws::String, Aws::String>>
  SendTextMessageRequest& WithContext(ContextT&& value) {
    SetContext(std::forward<ContextT>(value));
    return *this;
  }
  template <typename ContextKeyT = Aws::String, typename ContextValueT = Aws::String>
  SendTextMessageRequest& AddContext(ContextKeyT&& key, ContextValueT&& value) {
    m_contextHasBeenSet = true;
    m_context.emplace(std::forward<ContextKeyT>(key), std::forward<ContextValueT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>This field is used for any country-specific registration requirements.
   * Currently, this setting is only used when you send messages to recipients in
   * India using a sender ID. For more information see <a
   * href="https://docs.aws.amazon.com/pinpoint/latest/userguide/channels-sms-senderid-india.html">Special
   * requirements for sending SMS messages to recipients in India</a>. </p> <ul> <li>
   * <p> <code>IN_ENTITY_ID</code> The entity ID or Principal Entity (PE) ID that you
   * received after completing the sender ID registration process.</p> </li> <li> <p>
   * <code>IN_TEMPLATE_ID</code> The template ID that you received after completing
   * the sender ID registration process.</p>  <p>Make sure that the
   * Template ID that you specify matches your message template exactly. If your
   * message doesn't match the template that you provided during the registration
   * process, the mobile carriers might reject your message.</p>  </li>
   * </ul>
   */
  inline const Aws::Map<DestinationCountryParameterKey, Aws::String>& GetDestinationCountryParameters() const {
    return m_destinationCountryParameters;
  }
  inline bool DestinationCountryParametersHasBeenSet() const { return m_destinationCountryParametersHasBeenSet; }
  template <typename DestinationCountryParametersT = Aws::Map<DestinationCountryParameterKey, Aws::String>>
  void SetDestinationCountryParameters(DestinationCountryParametersT&& value) {
    m_destinationCountryParametersHasBeenSet = true;
    m_destinationCountryParameters = std::forward<DestinationCountryParametersT>(value);
  }
  template <typename DestinationCountryParametersT = Aws::Map<DestinationCountryParameterKey, Aws::String>>
  SendTextMessageRequest& WithDestinationCountryParameters(DestinationCountryParametersT&& value) {
    SetDestinationCountryParameters(std::forward<DestinationCountryParametersT>(value));
    return *this;
  }
  inline SendTextMessageRequest& AddDestinationCountryParameters(DestinationCountryParameterKey key, Aws::String value) {
    m_destinationCountryParametersHasBeenSet = true;
    m_destinationCountryParameters.emplace(key, value);
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>When set to true, the message is checked and validated, but isn't sent to the
   * end recipient. You are not charged for using <code>DryRun</code>.</p> <p>The
   * Message Parts per Second (MPS) limit when using <code>DryRun</code> is five. If
   * your origination identity has a lower MPS limit then the lower MPS limit is
   * used. For more information about MPS limits, see <a
   * href="https://docs.aws.amazon.com/sms-voice/latest/userguide/sms-limitations-mps.html">Message
   * Parts per Second (MPS) limits</a> in the <i>End User MessagingSMS User
   * Guide</i>..</p>
   */
  inline bool GetDryRun() const { return m_dryRun; }
  inline bool DryRunHasBeenSet() const { return m_dryRunHasBeenSet; }
  inline void SetDryRun(bool value) {
    m_dryRunHasBeenSet = true;
    m_dryRun = value;
  }
  inline SendTextMessageRequest& WithDryRun(bool value) {
    SetDryRun(value);
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The unique identifier for the protect configuration.</p>
   */
  inline const Aws::String& GetProtectConfigurationId() const { return m_protectConfigurationId; }
  inline bool ProtectConfigurationIdHasBeenSet() const { return m_protectConfigurationIdHasBeenSet; }
  template <typename ProtectConfigurationIdT = Aws::String>
  void SetProtectConfigurationId(ProtectConfigurationIdT&& value) {
    m_protectConfigurationIdHasBeenSet = true;
    m_protectConfigurationId = std::forward<ProtectConfigurationIdT>(value);
  }
  template <typename ProtectConfigurationIdT = Aws::String>
  SendTextMessageRequest& WithProtectConfigurationId(ProtectConfigurationIdT&& value) {
    SetProtectConfigurationId(std::forward<ProtectConfigurationIdT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>Set to true to enable message feedback for the message. When a user receives
   * the message you need to update the message status using
   * <a>PutMessageFeedback</a>.</p>
   */
  inline bool GetMessageFeedbackEnabled() const { return m_messageFeedbackEnabled; }
  inline bool MessageFeedbackEnabledHasBeenSet() const { return m_messageFeedbackEnabledHasBeenSet; }
  inline void SetMessageFeedbackEnabled(bool value) {
    m_messageFeedbackEnabledHasBeenSet = true;
    m_messageFeedbackEnabled = value;
  }
  inline SendTextMessageRequest& WithMessageFeedbackEnabled(bool value) {
    SetMessageFeedbackEnabled(value);
    return *this;
  }
  ///@}
 private:
  Aws::String m_destinationPhoneNumber;

  Aws::String m_originationIdentity;

  Aws::String m_messageBody;

  MessageType m_messageType{MessageType::NOT_SET};

  Aws::String m_keyword;

  Aws::String m_configurationSetName;

  Aws::String m_maxPrice;

  int m_timeToLive{0};

  Aws::Map<Aws::String, Aws::String> m_context;

  Aws::Map<DestinationCountryParameterKey, Aws::String> m_destinationCountryParameters;

  bool m_dryRun{false};

  Aws::String m_protectConfigurationId;

  bool m_messageFeedbackEnabled{false};
  bool m_destinationPhoneNumberHasBeenSet = false;
  bool m_originationIdentityHasBeenSet = false;
  bool m_messageBodyHasBeenSet = false;
  bool m_messageTypeHasBeenSet = false;
  bool m_keywordHasBeenSet = false;
  bool m_configurationSetNameHasBeenSet = false;
  bool m_maxPriceHasBeenSet = false;
  bool m_timeToLiveHasBeenSet = false;
  bool m_contextHasBeenSet = false;
  bool m_destinationCountryParametersHasBeenSet = false;
  bool m_dryRunHasBeenSet = false;
  bool m_protectConfigurationIdHasBeenSet = false;
  bool m_messageFeedbackEnabledHasBeenSet = false;
};

}  // namespace Model
}  // namespace PinpointSMSVoiceV2
}  // namespace Aws

==> aws-sdk-cpp-1.11.725-1-x86_64.pkg.tar.zst: usr/include/aws/pinpoint-sms-voice-v2/model/SendTextMessageRequest.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/utils/memory/stl/AWSMap.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/pinpoint-sms-voice-v2/PinpointSMSVoiceV2Request.h>
#include <aws/pinpoint-sms-voice-v2/PinpointSMSVoiceV2_EXPORTS.h>
#include <aws/pinpoint-sms-voice-v2/model/DestinationCountryParameterKey.h>
#include <aws/pinpoint-sms-voice-v2/model/MessageType.h>

#include <utility>

namespace Aws {
namespace PinpointSMSVoiceV2 {
namespace Model {

/**
 */
class SendTextMessageRequest : public PinpointSMSVoiceV2Request {
 public:
  AWS_PINPOINTSMSVOICEV2_API SendTextMessageRequest() = default;

  // Service request name is the Operation name which will send this request out,
  // each operation should has unique request name, so that we can get operation's name from this request.
  // Note: this is not true for response, multiple operations may have the same response name,
  // so we can not get operation's name from response.
  inline virtual const char* GetServiceRequestName() const override { return "SendTextMessage"; }

  AWS_PINPOINTSMSVOICEV2_API Aws::String SerializePayload() const override;

  AWS_PINPOINTSMSVOICEV2_API Aws::Http::HeaderValueCollection GetRequestSpecificHeaders() const override;

  ///@{
  /**
   * <p>The destination phone number in E.164 format.</p>
   */
  inline const Aws::String& GetDestinationPhoneNumber() const { return m_destinationPhoneNumber; }
  inline bool DestinationPhoneNumberHasBeenSet() const { return m_destinationPhoneNumberHasBeenSet; }
  template <typename DestinationPhoneNumberT = Aws::String>
  void SetDestinationPhoneNumber(DestinationPhoneNumberT&& value) {
    m_destinationPhoneNumberHasBeenSet = true;
    m_destinationPhoneNumber = std::forward<DestinationPhoneNumberT>(value);
  }
  template <typename DestinationPhoneNumberT = Aws::String>
  SendTextMessageRequest& WithDestinationPhoneNumber(DestinationPhoneNumberT&& value) {
    SetDestinationPhoneNumber(std::forward<DestinationPhoneNumberT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The origination identity of the message. This can be either the PhoneNumber,
   * PhoneNumberId, PhoneNumberArn, SenderId, SenderIdArn, PoolId, or PoolArn.</p>
   *  <p>If you are using a shared End User Messaging SMS resource then
   * you must use the full Amazon Resource Name(ARN).</p>
   */
  inline const Aws::String& GetOriginationIdentity() const { return m_originationIdentity; }
  inline bool OriginationIdentityHasBeenSet() const { return m_originationIdentityHasBeenSet; }
  template <typename OriginationIdentityT = Aws::String>
  void SetOriginationIdentity(OriginationIdentityT&& value) {
    m_originationIdentityHasBeenSet = true;
    m_originationIdentity = std::forward<OriginationIdentityT>(value);
  }
  template <typename OriginationIdentityT = Aws::String>
  SendTextMessageRequest& WithOriginationIdentity(OriginationIdentityT&& value) {
    SetOriginationIdentity(std::forward<OriginationIdentityT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The body of the text message.</p>
   */
  inline const Aws::String& GetMessageBody() const { return m_messageBody; }
  inline bool MessageBodyHasBeenSet() const { return m_messageBodyHasBeenSet; }
  template <typename MessageBodyT = Aws::String>
  void SetMessageBody(MessageBodyT&& value) {
    m_messageBodyHasBeenSet = true;
    m_messageBody = std::forward<MessageBodyT>(value);
  }
  template <typename MessageBodyT = Aws::String>
  SendTextMessageRequest& WithMessageBody(MessageBodyT&& value) {
    SetMessageBody(std::forward<MessageBodyT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The type of message. Valid values are for messages that are critical or
   * time-sensitive and PROMOTIONAL for messages that aren't critical or
   * time-sensitive.</p>
   */
  inline MessageType GetMessageType() const { return m_messageType; }
  inline bool MessageTypeHasBeenSet() const { return m_messageTypeHasBeenSet; }
  inline void SetMessageType(MessageType value) {
    m_messageTypeHasBeenSet = true;
    m_messageType = value;
  }
  inline SendTextMessageRequest& WithMessageType(MessageType value) {
    SetMessageType(value);
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>When you register a short code in the US, you must specify a program name. If
   * you don’t have a US short code, omit this attribute.</p>
   */
  inline const Aws::String& GetKeyword() const { return m_keyword; }
  inline bool KeywordHasBeenSet() const { return m_keywordHasBeenSet; }
  template <typename KeywordT = Aws::String>
  void SetKeyword(KeywordT&& value) {
    m_keywordHasBeenSet = true;
    m_keyword = std::forward<KeywordT>(value);
  }
  template <typename KeywordT = Aws::String>
  SendTextMessageRequest& WithKeyword(KeywordT&& value) {
    SetKeyword(std::forward<KeywordT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The name of the configuration set to use. This can be either the
   * ConfigurationSetName or ConfigurationSetArn.</p>
   */
  inline const Aws::String& GetConfigurationSetName() const { return m_configurationSetName; }
  inline bool ConfigurationSetNameHasBeenSet() const { return m_configurationSetNameHasBeenSet; }
  template <typename ConfigurationSetNameT = Aws::String>
  void SetConfigurationSetName(ConfigurationSetNameT&& value) {
    m_configurationSetNameHasBeenSet = true;
    m_configurationSetName = std::forward<ConfigurationSetNameT>(value);
  }
  template <typename ConfigurationSetNameT = Aws::String>
  SendTextMessageRequest& WithConfigurationSetName(ConfigurationSetNameT&& value) {
    SetConfigurationSetName(std::forward<ConfigurationSetNameT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The maximum amount that you want to spend, in US dollars, per each text
   * message. If the calculated amount to send the text message is greater than
   * <code>MaxPrice</code>, the message is not sent and an error is returned.</p>
   */
  inline const Aws::String& GetMaxPrice() const { return m_maxPrice; }
  inline bool MaxPriceHasBeenSet() const { return m_maxPriceHasBeenSet; }
  template <typename MaxPriceT = Aws::String>
  void SetMaxPrice(MaxPriceT&& value) {
    m_maxPriceHasBeenSet = true;
    m_maxPrice = std::forward<MaxPriceT>(value);
  }
  template <typename MaxPriceT = Aws::String>
  SendTextMessageRequest& WithMaxPrice(MaxPriceT&& value) {
    SetMaxPrice(std::forward<MaxPriceT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>How long the text message is valid for, in seconds. By default this is 72
   * hours. If the messages isn't handed off before the TTL expires we stop
   * attempting to hand off the message and return <code>TTL_EXPIRED</code>
   * event.</p>
   */
  inline int GetTimeToLive() const { return m_timeToLive; }
  inline bool TimeToLiveHasBeenSet() const { return m_timeToLiveHasBeenSet; }
  inline void SetTimeToLive(int value) {
    m_timeToLiveHasBeenSet = true;
    m_timeToLive = value;
  }
  inline SendTextMessageRequest& WithTimeToLive(int value) {
    SetTimeToLive(value);
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>You can specify custom data in this field. If you do, that data is logged to
   * the event destination.</p>
   */
  inline const Aws::Map<Aws::String, Aws::String>& GetContext() const { return m_context; }
  inline bool ContextHasBeenSet() const { return m_contextHasBeenSet; }
  template <typename ContextT = Aws::Map<Aws::String, Aws::String>>
  void SetContext(ContextT&& value) {
    m_contextHasBeenSet = true;
    m_context = std::forward<ContextT>(value);
  }
  template <typename ContextT = Aws::Map<Aws::String, Aws::String>>
  SendTextMessageRequest& WithContext(ContextT&& value) {
    SetContext(std::forward<ContextT>(value));
    return *this;
  }
  template <typename ContextKeyT = Aws::String, typename ContextValueT = Aws::String>
  SendTextMessageRequest& AddContext(ContextKeyT&& key, ContextValueT&& value) {
    m_contextHasBeenSet = true;
    m_context.emplace(std::forward<ContextKeyT>(key), std::forward<ContextValueT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>This field is used for any country-specific registration requirements.
   * Currently, this setting is only used when you send messages to recipients in
   * India using a sender ID. For more information see <a
   * href="https://docs.aws.amazon.com/pinpoint/latest/userguide/channels-sms-senderid-india.html">Special
   * requirements for sending SMS messages to recipients in India</a>. </p> <ul> <li>
   * <p> <code>IN_ENTITY_ID</code> The entity ID or Principal Entity (PE) ID that you
   * received after completing the sender ID registration process.</p> </li> <li> <p>
   * <code>IN_TEMPLATE_ID</code> The template ID that you received after completing
   * the sender ID registration process.</p>  <p>Make sure that the
   * Template ID that you specify matches your message template exactly. If your
   * message doesn't match the template that you provided during the registration
   * process, the mobile carriers might reject your message.</p>  </li>
   * </ul>
   */
  inline const Aws::Map<DestinationCountryParameterKey, Aws::String>& GetDestinationCountryParameters() const {
    return m_destinationCountryParameters;
  }
  inline bool DestinationCountryParametersHasBeenSet() const { return m_destinationCountryParametersHasBeenSet; }
  template <typename DestinationCountryParametersT = Aws::Map<DestinationCountryParameterKey, Aws::String>>
  void SetDestinationCountryParameters(DestinationCountryParametersT&& value) {
    m_destinationCountryParametersHasBeenSet = true;
    m_destinationCountryParameters = std::forward<DestinationCountryParametersT>(value);
  }
  template <typename DestinationCountryParametersT = Aws::Map<DestinationCountryParameterKey, Aws::String>>
  SendTextMessageRequest& WithDestinationCountryParameters(DestinationCountryParametersT&& value) {
    SetDestinationCountryParameters(std::forward<DestinationCountryParametersT>(value));
    return *this;
  }
  inline SendTextMessageRequest& AddDestinationCountryParameters(DestinationCountryParameterKey key, Aws::String value) {
    m_destinationCountryParametersHasBeenSet = true;
    m_destinationCountryParameters.emplace(key, value);
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>When set to true, the message is checked and validated, but isn't sent to the
   * end recipient. You are not charged for using <code>DryRun</code>.</p> <p>The
   * Message Parts per Second (MPS) limit when using <code>DryRun</code> is five. If
   * your origination identity has a lower MPS limit then the lower MPS limit is
   * used. For more information about MPS limits, see <a
   * href="https://docs.aws.amazon.com/sms-voice/latest/userguide/sms-limitations-mps.html">Message
   * Parts per Second (MPS) limits</a> in the <i>End User Messaging SMS User
   * Guide</i>..</p>
   */
  inline bool GetDryRun() const { return m_dryRun; }
  inline bool DryRunHasBeenSet() const { return m_dryRunHasBeenSet; }
  inline void SetDryRun(bool value) {
    m_dryRunHasBeenSet = true;
    m_dryRun = value;
  }
  inline SendTextMessageRequest& WithDryRun(bool value) {
    SetDryRun(value);
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The unique identifier for the protect configuration.</p>
   */
  inline const Aws::String& GetProtectConfigurationId() const { return m_protectConfigurationId; }
  inline bool ProtectConfigurationIdHasBeenSet() const { return m_protectConfigurationIdHasBeenSet; }
  template <typename ProtectConfigurationIdT = Aws::String>
  void SetProtectConfigurationId(ProtectConfigurationIdT&& value) {
    m_protectConfigurationIdHasBeenSet = true;
    m_protectConfigurationId = std::forward<ProtectConfigurationIdT>(value);
  }
  template <typename ProtectConfigurationIdT = Aws::String>
  SendTextMessageRequest& WithProtectConfigurationId(ProtectConfigurationIdT&& value) {
    SetProtectConfigurationId(std::forward<ProtectConfigurationIdT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>Set to true to enable message feedback for the message. When a user receives
   * the message you need to update the message status using
   * <a>PutMessageFeedback</a>.</p>
   */
  inline bool GetMessageFeedbackEnabled() const { return m_messageFeedbackEnabled; }
  inline bool MessageFeedbackEnabledHasBeenSet() const { return m_messageFeedbackEnabledHasBeenSet; }
  inline void SetMessageFeedbackEnabled(bool value) {
    m_messageFeedbackEnabledHasBeenSet = true;
    m_messageFeedbackEnabled = value;
  }
  inline SendTextMessageRequest& WithMessageFeedbackEnabled(bool value) {
    SetMessageFeedbackEnabled(value);
    return *this;
  }
  ///@}
 private:
  Aws::String m_destinationPhoneNumber;

  Aws::String m_originationIdentity;

  Aws::String m_messageBody;

  MessageType m_messageType{MessageType::NOT_SET};

  Aws::String m_keyword;

  Aws::String m_configurationSetName;

  Aws::String m_maxPrice;

  int m_timeToLive{0};

  Aws::Map<Aws::String, Aws::String> m_context;

  Aws::Map<DestinationCountryParameterKey, Aws::String> m_destinationCountryParameters;

  bool m_dryRun{false};

  Aws::String m_protectConfigurationId;

  bool m_messageFeedbackEnabled{false};
  bool m_destinationPhoneNumberHasBeenSet = false;
  bool m_originationIdentityHasBeenSet = false;
  bool m_messageBodyHasBeenSet = false;
  bool m_messageTypeHasBeenSet = false;
  bool m_keywordHasBeenSet = false;
  bool m_configurationSetNameHasBeenSet = false;
  bool m_maxPriceHasBeenSet = false;
  bool m_timeToLiveHasBeenSet = false;
  bool m_contextHasBeenSet = false;
  bool m_destinationCountryParametersHasBeenSet = false;
  bool m_dryRunHasBeenSet = false;
  bool m_protectConfigurationIdHasBeenSet = false;
  bool m_messageFeedbackEnabledHasBeenSet = false;
};

}  // namespace Model
}  // namespace PinpointSMSVoiceV2
}  // namespace Aws
